@@ -8,13 +8,17 @@ package Net::POP3S;
 
 use vars qw ( $VERSION @ISA );
 
-$VERSION = "0.06";
+$VERSION = '0.07';
 
+use strict;
 use base qw ( Net::POP3 );
 use Net::Cmd;  # import CMD_OK, CMD_MORE, ...
 use Net::Config;
 
 eval {
+    require IO::Socket::IP
+	and unshift @ISA, 'IO::Socket::IP';
+} or eval {
     require IO::Socket::INET6
 	and unshift @ISA, 'IO::Socket::INET6';
 } or do {
@@ -22,8 +26,6 @@ eval {
 	and unshift @ISA, 'IO::Socket::INET';
 };
 
-use strict;
-
 # Override to support SSL/TLS.
 sub new {
   my $self = shift;
@@ -167,6 +169,12 @@ sub auth {
   $self->SUPER::auth($username, $password);
 }
 
+# Fix #121006 no timeout issue.
+sub getline {
+  my $self = shift;
+  $self->Net::Cmd::getline(@_);
+}
+
 1;
 
 __END__
